@@ -61,29 +61,7 @@ class DataModel():
             retlst.append(retdict)
         return retlst
 
-    def get_gchart_json(self, lst, list_columns, label_columns):
-        """
-            Get google charts JSON
-        """
-        json_cols = []
-        for col_name in list_columns:
-            col = {'id': col_name, 'label': label_columns.get(col_name)}
-            if self.is_string(col_name):
-                col['type'] = 'string'
-            elif self.is_integer(col_name):
-                col['type'] = 'int'
-            elif self.is_date(col_name):
-                col['type'] = 'date'
-            json_cols.append(col)
-        json_data = []
-        for item in list_columns:
-            data = {}
-            for col in list_columns:
-                data['c'] = col
-                data['v'] = self._get_attr_value(item, col)
-            json_data.append(data)
-        return [{'cols': json_cols, 'rows': json_data}]
-
+    
 
 class SQLAModel(DataModel):
     """
@@ -165,17 +143,6 @@ class SQLAModel(DataModel):
         group = GroupByCol(group_by, 'Group by')
         return group.apply(query_result)
 
-    # still not in use
-    def query_group(self, group_bys, filters=None):
-        query = self.session.query(self.obj)
-        query = self._get_base_query(query=query, filters=filters)
-        query_result = query.all()
-        for group_by in group_bys:
-            result = group_by.apply2(query_result)
-            log.debug("QG: %s" % result)
-        return result
-
-
     def query_month_group(self, group_by='', filters=None):
         query = self.session.query(self.obj)
         query = self._get_base_query(query=query, filters=filters)
@@ -183,7 +150,6 @@ class SQLAModel(DataModel):
         group = GroupByDateMonth(group_by, 'Group by Month')
         return group.apply(query_result)
 
-
     def query_year_group(self, group_by='', filters=None):
         query = self.session.query(self.obj)
         query = self._get_base_query(query=query, filters=filters)
