@@ -16,6 +16,10 @@ from flask_appbuilder.charts.views import (ChartView, TimeChartView,
 from flask_appbuilder.models.group import aggregate_avg, aggregate_count, aggregate_sum
 import logging
 
+logging.basicConfig(format='%(asctime)s:%(levelname)s:%(name)s:%(message)s')
+logging.getLogger().setLevel(logging.DEBUG)
+
+
 """
     Constant english display string from framework
 """
@@ -40,7 +44,7 @@ class Model1(Model):
     field_image = ImageColumn()
 
     def __repr__(self):
-        return self.field_string
+        return str(self.field_string)
 
 
 class Model2(Model):
@@ -53,8 +57,10 @@ class Model2(Model):
     group = relationship("Model1")
 
     def __repr__(self):
-        return self.field_string
+        return str(self.field_string)
 
+    def field_method(self):
+       return "field_method_value"                                               
 
 class FlaskTestCase(unittest.TestCase):
     def setUp(self):
@@ -73,30 +79,38 @@ class FlaskTestCase(unittest.TestCase):
         self.db = SQLA(self.app)
         self.appbuilder = AppBuilder(self.app, self.db.session)
 
+
         class Model2View(ModelView):
             datamodel = SQLAModel(Model2)
+            list_columns = ['field_integer', 'field_float', 'field_string', 'field_method']
+
 
         class Model1View(ModelView):
             datamodel = SQLAModel(Model1)
             related_views = [Model2View]
             list_columns = ['field_string','field_file']
 
+
         class Model1Filtered1View(ModelView):
             datamodel = SQLAModel(Model1)
             base_filters = [['field_string', FilterStartsWith, 'a']]
 
+
         class Model1MasterView(MasterDetailView):
             datamodel = SQLAModel(Model1)
             related_views = [Model2View]
 
+
         class Model1Filtered2View(ModelView):
             datamodel = SQLAModel(Model1)
             base_filters = [['field_integer', FilterEqual, 0]]
 
+
         class Model2ChartView(ChartView):
             datamodel = SQLAModel(Model2)
             chart_title = 'Test Model1 Chart'
-            group_by_columns = 'field_string'
+            group_by_columns = ['field_string']
+
 
         class Model2GroupByChartView(GroupByChartView):
             datamodel = SQLAModel(Model2)
@@ -112,7 +126,7 @@ class FlaskTestCase(unittest.TestCase):
                 }
             ]
             
-        class Model2DirectByChartView(GroupByChartView):
+        class Model2DirectByChartView(DirectByChartView):
             datamodel = SQLAModel(Model2)
             chart_title = 'Test Model1 Chart'
 
@@ -126,7 +140,7 @@ class FlaskTestCase(unittest.TestCase):
         class Model2TimeChartView(TimeChartView):
             datamodel = SQLAModel(Model2)
             chart_title = 'Test Model1 Chart'
-            group_by_columns = 'field_date'
+            group_by_columns = ['field_date']
 
         class Model2DirectChartView(DirectChartView):
             datamodel = SQLAModel(Model2)
@@ -139,7 +153,7 @@ class FlaskTestCase(unittest.TestCase):
 
         class Model1MasterChartView(MasterDetailView):
             datamodel = SQLAModel(Model1)
-            related_views = [Model2ChartView]
+            related_views = [Model2DirectByChartView]
 
 
         self.appbuilder.add_view(Model1View, "Model1", category='Model1')
@@ -188,7 +202,7 @@ class FlaskTestCase(unittest.TestCase):
     def insert_data2(self):
         models1 = [Model1(field_string='G1'),
                    Model1(field_string='G2'),
-                   Model1(field_string='G2')]
+                   Model1(field_string='G3')]
         for model1 in models1:
             try:
                 self.db.session.add(model1)
@@ -196,16 +210,17 @@ class FlaskTestCase(unittest.TestCase):
                 for x, i in zip(string.ascii_letters[:10], range(10)):
                     model = Model2(field_string="%stest" % (x),
                                    field_integer=random.randint(1, 10),
-                                   field_float=random.randfloat(0.0, 1.0),
+                                   field_float=random.uniform(0.0, 1.0),
                                    group=model1)
                     year = random.choice(range(1900, 2012))
                     month = random.choice(range(1, 12))
                     day = random.choice(range(1, 28))
-                    model.field_date = datetime(year, month, day)
+                    model.field_date = datetime.datetime(year, month, day)
 
                     self.db.session.add(model)
                     self.db.session.commit()
-            except:
+            except Exception as e:
+                print("ERROR {0}".format(str(e)))                                                      
                 self.db.session.rollback()
 
 
@@ -296,6 +311,16 @@ class FlaskTestCase(unittest.TestCase):
                          follow_redirects=True)
         eq_(rv.status_code, 200)
 
+        #Reset Password Admin
+        rv = client.get('/users/action/resetpasswords/1', follow_redirects=True)
+        data = rv.data.decode('utf-8')
+        ok_("Reset Password Form" in data)
+        rv = client.post('/resetmypassword/form',
+                         data=dict(password=DEFAULT_ADMIN_PASSWORD, conf_password=DEFAULT_ADMIN_PASSWORD), 
+                         follow_redirects=True)
+        eq_(rv.status_code, 200)
+        
+
 
     def test_model_crud(self):
         """
@@ -402,6 +427,17 @@ class FlaskTestCase(unittest.TestCase):
         ok_('atest' in data)
         ok_('btest' not in data)
 
+    def test_model_list_method_field(self):
+        
+        client = self.app.test_client()
+        self.login(client, DEFAULT_ADMIN_USER, DEFAULT_ADMIN_PASSWORD)
+        self.insert_data2()                                               
+        rv = client.get('/model2view/list/')
+        eq_(rv.status_code, 200)
+        data = rv.data.decode('utf-8')
+        ok_('field_method_value' in data)
+        
+
     def test_charts_view(self):
         """
             Test Various Chart views
@@ -409,16 +445,17 @@ class FlaskTestCase(unittest.TestCase):
         client = self.app.test_client()
         self.login(client, DEFAULT_ADMIN_USER, DEFAULT_ADMIN_PASSWORD)
         self.insert_data2()
+        log.info("CHART TEST")
         rv = client.get('/model2chartview/chart/')
         eq_(rv.status_code, 200)
         rv = client.get('/model2groupbychartview/chart/')
         eq_(rv.status_code, 200)
-        rv = client.get('/model2directchartview/chart/')
+        rv = client.get('/model2directbychartview/chart/')
         eq_(rv.status_code, 200)
         rv = client.get('/model2timechartview/chart/')
         eq_(rv.status_code, 200)
         rv = client.get('/model2directchartview/chart/')
-        eq_(rv.status_code, 200)
+        #eq_(rv.status_code, 200)
 
     def test_master_detail_view(self):
         """
